from configglue.pyschema import Schema, StringConfigOption, BoolConfigOption

SOUND_VALS = 'Mute 10 20 30 40 50 60 70 80 90 100'.split()

class EnumConfigOption(StringConfigOption):

    def __init__(self, values, default=None):
        if default is None:
            default = values[0]
        self.values = dict((v.lower(), v) for v in values)
        super(EnumConfigOption, self).__init__(default=default)

    def parse(self, value):
        """Take the value as string, and return the real value."""
        v_lower = value.lower()
        if v_lower not in self.values:
            raise ValueError("Invalid value for option %s (got: %r)" % (
                                                            self.name, value))

        return self.values[v_lower]


class ConfigSchema(Schema):

    username = StringConfigOption(default='anonymous')
    fullscreen = BoolConfigOption()
    sound_volume = EnumConfigOption(values=SOUND_VALS, default='70')
    music_volume = EnumConfigOption(values=SOUND_VALS, default='70')
