# This code is part of the 'enjuewemela' game
# License: GPLv3
# Main author: Facundo Batista
# Code, bug tracker, etc:
#   https://launchpad.net/enjuewemela/
#

"""Module to load and manage all the sounds."""

import os
import random

import pyglet

import config

# list of voices and effects, with each volume
EFFECTS = [
    ("pumba", .2),
    ("tic", .2),
    ("explosion", .9),
    ("magicdisap", .9),
]

VOICES = [
    ("game_over", 1),
    ("not_yet", 1),
    ("new_level", 1),
]

class Sounds(object):
    """Manager class for the sounds."""

    def __init__(self, locale="en"):
        self._sounds = {}

        pyglet.resource.path.append(os.path.join(config.BASEDIR,
                                                 'audio', 'effects'))
        pyglet.resource.path.append(os.path.join(config.BASEDIR,
                                                 'audio', 'voices', locale))
        pyglet.resource.reindex()

        for snd, vol in EFFECTS + VOICES:
            if snd in self._sounds:
                raise ValueError("Repeated resource in sound.py")
            resource = pyglet.resource.media(snd + '.ogg', streaming=False)
            self._sounds[snd] = (vol, resource)

        self.volume = 1

    def play_wrapper(self, snd):
        """Return an object whose .play() plays this sound."""
        class PlayWrapper(object):
            """Wrapper."""
            # pylint: disable-msg=E0213
            def play(_):
                """Actually play the sound."""
                self.play(snd)
        return PlayWrapper()

    def play(self, snd):
        """Play a sound."""
        if not self.volume:
            return

        (volume, sound) = self._sounds[snd]
        # setting the volume here is a workaround for some pyglet/avbin bug
        sound.play().volume = volume * self.volume

sounds = Sounds()



# music!

music_player = pyglet.media.Player()

class Music(object):
    """Manager class for the music."""

    def __init__(self):
        # index music path and get the filenames
        music_path = os.path.join(config.BASEDIR, 'audio', 'music')
        pyglet.resource.path.append(music_path)
        pyglet.resource.reindex()
        self.music_fnames = [x for x in os.listdir(music_path)
                             if x[-3:] == 'ogg']
        self._playing = True
        self._volume = .2
        self.on_eos()

    @music_player.event
    def on_eos(self):
        if not self._volume:
            return

        to_play = random.choice(self.music_fnames)
        print "Random music", to_play
        music_player.volume = self._volume
        music_player.queue(pyglet.resource.media(to_play, streaming=True))
        music_player.play()
        music_player.eos_action = 'next'

    def _set_volume(self, value):
        """Set the music volume."""
        if value == 0:
            music_player.pause()
        else:
            self._volume = value
            music_player.volume = value
            music_player.play()

    def _get_volume(self):
        """Get the music volume."""
        return self._volume

    volume = property(_get_volume, _set_volume)

music = Music()
